==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/themed/LinkRow.js <==
import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
export function LinkRow(props) {
    const { label, marginRem, onPress, renderIcon = (theme) => (React.createElement(FontAwesome5, { name: "chevron-right", color: theme.iconTappable, size: theme.rem(1) })) } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const spacingStyles = Object.assign({}, sidesToPadding(mapSides(fixSides(marginRem, 0.5), theme.rem)));
    return (React.createElement(TouchableOpacity, { accessible: false, style: [styles.container, spacingStyles], onPress: onPress },
        label == null ? null : (React.createElement(Text, { accessible: true, style: styles.text }, label)),
        React.createElement(Text, { style: styles.icon }, renderIcon(theme))));
}
const getStyles = cacheStyles((theme) => {
    return {
        container: {
            alignItems: 'center',
            flexDirection: 'row'
        },
        icon: {
            color: theme.iconTappable,
            fontSize: theme.rem(1),
            marginLeft: theme.rem(1)
        },
        text: {
            color: theme.primaryText,
            flex: 1,
            fontFamily: theme.fontFamily,
            fontSize: theme.rem(1)
        }
    };
});

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/themed/LinkRow.js <==
import * as React from 'react';
import { Text } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { EdgeTouchableOpacity } from '../common/EdgeTouchableOpacity';
import { useTheme } from '../services/ThemeContext';
export function LinkRow(props) {
    const { label, marginRem, onPress, renderIcon = (theme) => (React.createElement(FontAwesome5, { name: "chevron-right", color: theme.iconTappable, size: theme.rem(1) })) } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const spacingStyles = Object.assign({}, sidesToPadding(mapSides(fixSides(marginRem, 0.5), theme.rem)));
    return (React.createElement(EdgeTouchableOpacity, { accessible: false, style: [styles.container, spacingStyles], onPress: onPress },
        label == null ? null : (React.createElement(Text, { accessible: true, style: styles.text }, label)),
        React.createElement(Text, { style: styles.icon }, renderIcon(theme))));
}
const getStyles = cacheStyles((theme) => {
    return {
        container: {
            alignItems: 'center',
            flexDirection: 'row'
        },
        icon: {
            color: theme.iconTappable,
            fontSize: theme.rem(1),
            marginLeft: theme.rem(1)
        },
        text: {
            color: theme.primaryText,
            flex: 1,
            fontFamily: theme.fontFamily,
            fontSize: theme.rem(1)
        }
    };
});
